Salut Changelog
==============

Salut follows the Semantic Versioning standard, although not for development
before version 1. Read more at http://semvar.org


Version 0.1.4
-------------

Released on May 30nd 2014

- Fix a bug when the FQDN is returned from browsing services


Version 0.1.3
-------------

Released on May 22nd 2013

- Fix a bug that happens when browsing before network is up


Version 0.1.2
-------------

Released on January 22nd 2013

- Include this changes file with setup


Version 0.1.1
-------------

Released on January 22nd 2013

- Add readme and license files with setup


Version 0.1.0
-------------

Released on January 22nd 2013

- First release
